'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();
/**
 * Module dependencies.
 */

var _constants = require('./constants');

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Export UkModulusChecking.
 */

var UkModulusChecking = function () {

  /**
   * Constructor.
   */

  function UkModulusChecking(_ref) {
    var _ref$accountNumber = _ref.accountNumber,
        accountNumber = _ref$accountNumber === undefined ? '' : _ref$accountNumber,
        _ref$sortCode = _ref.sortCode,
        sortCode = _ref$sortCode === undefined ? '' : _ref$sortCode;

    _classCallCheck(this, UkModulusChecking);

    this.accountNumber = this.sanitize(accountNumber);
    this.sortCode = this.sanitize(sortCode);
    this.sortCodeSubstitutes = this.loadScsubtab();
    this.weightTable = this.loadValacdos();
  }

  /**
   * Get check weight.
   */

  _createClass(UkModulusChecking, [{
    key: 'getCheckWeight',
    value: function getCheckWeight(check, number) {
      if (check.exception === 2) {
        if (this.pickPosition(number, 'a') !== 0 && this.pickPosition(number, 'g') !== 9) {
          return [0, 0, 1, 2, 5, 3, 6, 4, 8, 7, 10, 9, 3, 1];
        }

        if (this.pickPosition(number, 'a') !== 0 && this.pickPosition(number, 'g') === 9) {
          return [0, 0, 0, 0, 0, 0, 0, 0, 8, 7, 10, 9, 3, 1];
        }
      }

      if (check.exception === 7) {
        if (this.pickPosition(number, 'g') === 9) {
          return [0, 0, 0, 0, 0, 0, 0, 0, check.c, check.d, check.e, check.f, check.g, check.h];
        }
      }

      if (check.exception === 10) {
        var ab = number.charAt(_constants.positions.a) + number.charAt(_constants.positions.b);

        if (ab === '09' || ab === '99' && this.pickPosition(number, 'b') === 9) {
          return [0, 0, 0, 0, 0, 0, 0, 0, check.c, check.d, check.e, check.f, check.g, check.h];
        }
      }

      return [check.u, check.v, check.w, check.x, check.y, check.z, check.a, check.b, check.c, check.d, check.e, check.f, check.g, check.h];
    }

    /**
     * Get number to be used in validation process. (sorting code + account number).
     */

  }, {
    key: 'getNumber',
    value: function getNumber(check, number) {
      var sortCode = this.sortCode;

      number = number || this.accountNumber;

      if (check.exception === 5) {
        sortCode = this.getSubstitute(sortCode) || sortCode;
      } else if (check.exception === 8) {
        sortCode = '090126';
      } else if (check.exception === 9) {
        sortCode = '309634';
      }

      return '' + sortCode + number;
    }

    /**
     * Get sorting code checks.
     */

  }, {
    key: 'getSortCodeChecks',
    value: function getSortCodeChecks() {
      var checks = [];
      var sortCode = parseInt(this.sortCode, 10);

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = this.weightTable[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var check = _step.value;

          // All checks containing the sort code in the `weight range` can/must be performed.
          if (sortCode >= check.start && sortCode <= check.end) {
            checks.push(check);
          }

          // There may be one or two entries in the table for the sorting code,
          // depending on whether one or two modulus checks must be carried out.
          if (checks.length === 2) {
            return checks;
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      return checks;
    }

    /**
     * Sorting code substitution.
     */

  }, {
    key: 'getSubstitute',
    value: function getSubstitute(sortCode) {
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = this.sortCodeSubstitutes[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var substitute = _step2.value;

          if (substitute.original === parseInt(sortCode, 10)) {
            return parseInt(substitute.substitute, 10);
          }
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }

      return parseInt(sortCode, 10);
    }

    /**
     * Is check skippable.
     */

  }, {
    key: 'isCheckSkippable',
    value: function isCheckSkippable(check, number) {
      if (check.exception === 3 && (this.pickPosition(number, 'c') === 6 || this.pickPosition(number, 'c') === 9)) {
        return true;
      }

      if (check.exception === 6 && this.pickPosition(number, 'a') >= 4 && this.pickPosition(number, 'a') <= 8 && this.pickPosition(number, 'g') === this.pickPosition(number, 'h')) {
        return true;
      }

      return false;
    }

    /**
     * Is check valid.
     */

  }, {
    key: 'isCheckValid',
    value: function isCheckValid(check, number) {
      number = this.getNumber(check, number);

      if (this.isCheckSkippable(check, number)) {
        return true;
      }

      var module = check.mod === 'MOD11' ? 11 : 10;
      var weight = this.getCheckWeight(check, number);

      // Multiply each number in the sorting code and account number with the corresponding number in the weight.
      var weightedAccount = [];

      for (var i = 0; i < 14; i++) {
        weightedAccount[i] = parseInt(number.charAt(i), 10) * parseInt(weight[i], 10);
      }

      // Add all the results together.
      if (check.mod === 'DBLAL') {
        weightedAccount = weightedAccount.join('').split('');
      }

      var total = weightedAccount.reduce(function (previous, current) {
        return parseInt(previous, 10) + parseInt(current, 10);
      });

      // This effectively places a financial institution number (580149) before the sorting code and account
      // number which is subject to the alternate doubling as well.
      if (check.exception === 1) {
        total += 27;
      }

      // Calculate remainder.
      var remainder = total % module;

      // Exception handling.
      if (check.exception === 4) {
        return remainder === this.pickPosition(number, 'g') + this.pickPosition(number, 'h');
      }

      if (check.exception === 5) {
        if (check.mod === 'DBLAL') {
          if (remainder === 0 && this.pickPosition(number, 'h') === 0) {
            return true;
          }

          return this.pickPosition(number, 'h') === 10 - remainder;
        }

        if (remainder === 1) {
          return false;
        }

        if (remainder === 0 && this.pickPosition(number, 'g') === 0) {
          return true;
        }

        return this.pickPosition(number, 'g') === 11 - remainder;
      }

      return remainder === 0;
    }

    /**
     * Is valid.
     */

  }, {
    key: 'isValid',
    value: function isValid() {
      if (this.accountNumber.length < 6 || this.accountNumber.length > 10 || this.sortCode.length !== 6) {
        return false;
      }

      var checks = this.getSortCodeChecks();

      // If no range is found that contains the sorting code, there is no modulus check that can be performed.
      // The sorting code and account number should be presumed valid unless other evidence implies otherwise.
      if (checks.length === 0) {
        return true;
      }

      var firstCheck = checks[0];

      if (this.isCheckValid(firstCheck)) {
        if (checks.length === 1 || [2, 9, 10, 11, 12, 13, 14].indexOf(firstCheck.exception) !== -1) {
          return true;
        }

        // Verify second check.
        return this.isCheckValid(checks[1]);
      }

      if (firstCheck.exception === 14) {
        if ([0, 1, 9].indexOf(parseInt(this.accountNumber.charAt(7), 10)) === -1) {
          return false;
        }

        //  If the 8th digit is 0, 1 or 9, then remove the digit from the account number and insert a 0 as the 1st digit for check purposes only
        return this.isCheckValid(checks[0], '0' + this.accountNumber.substring(7, 0));
      }

      if (checks.length === 1 || [2, 9, 10, 11, 12, 13, 14].indexOf(firstCheck.exception) === -1) {
        return false;
      }

      // Verify second check.
      return this.isCheckValid(checks[1]);
    }

    /**
     * Load scsubtab file.
     */

  }, {
    key: 'loadScsubtab',
    value: function loadScsubtab() {
      var content = '938173 938017\r\n938289 938068\r\n938297 938076\r\n938600 938611\r\n938602 938343\r\n938604 938603\r\n938608 938408\r\n938609 938424\r\n938613 938017\r\n938616 938068\r\n938618 938657\r\n938620 938343\r\n938622 938130\r\n938628 938181\r\n938643 938246\r\n938647 938611\r\n938648 938246\r\n938649 938394\r\n938651 938335\r\n938653 938424\r\n938654 938621\r\n';
      var scsubtab = [];

      content.split('\r\n').forEach(function (line) {
        var data = line.split(/\s+/);

        scsubtab.push({
          original: parseInt(data[0], 10),
          substitute: parseInt(data[1], 10)
        });
      });

      return scsubtab;
    }

    /**
     * Load valacdos file.
     */

  }, {
    key: 'loadValacdos',
    value: function loadValacdos() {
      var content = '010004 016715 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n040004 040004 DBLAL    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n040010 040014 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n040010 040014 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n040015 040015 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n040020 040023 MOD11    0    2    0    0    9    1    2    8    4    3    7    5    6    1\r\n040024 040039 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n040024 040039 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n040040 040059 MOD11    0    2    0    0    9    1    2    8    4    3    7    5    6    1\r\n040072 040073 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n040074 040075 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n040082 040082 MOD10    2    1    2    1    2    1    0   64   32   16    8    4    2    1\r\n040400 041311 DBLAL    1    3    4    3    9    3    1    7    5    5    4    5    2    4\r\n041312 041312 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n041313 041399 DBLAL    1    3    4    3    9    3    1    7    5    5    4    5    2    4\r\n041400 041449 MOD11    0    2    0    0    9    1    2    8    4    3    7    5    6    1\r\n050000 050020 MOD11    0    0    0    0    0    0    2    1    7    5    8    2    4    1\r\n050022 058999 MOD11    0    0    0    0    0    0    2    1    7    5    8    2    4    1\r\n070030 070030 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070040 070040 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070055 070055 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070066 070066 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070116 070116 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1  12\r\n070116 070116 MOD10    0    3    2    4    5    8    9    4    5    6    7    8    9   -1  13\r\n070246 070246 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070436 070436 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070806 070806 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n070976 070976 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071040 071040 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071096 071096 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071120 071120 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071226 071226 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071306 071306 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071310 071310 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071350 071350 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071490 071490 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071520 071520 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071660 071660 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n071986 071986 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1\r\n074456 074456 MOD11    0    0    7    6    5    8    9    4    5    6    7    8    9   -1  12\r\n074456 074456 MOD10    0    3    2    4    5    8    9    4    5    6    7    8    9   -1  13\r\n080211 080211 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n080228 080228 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n086001 086001 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n086020 086020 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n086086 086086 MOD11    0    0    0    0    0    8    9    4    5    6    7    8    9   -1\r\n086090 086090 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1   8\r\n089000 089999 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n090013 090013 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090105 090105 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090118 090118 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n090126 090129 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090131 090136 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n090150 090156 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n090180 090185 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090190 090196 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090204 090204 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090222 090222 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090356 090356 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n090500 090599 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090704 090704 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090705 090705 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090710 090710 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090715 090715 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090720 090726 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n090736 090739 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n090790 090790 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n091600 091600 MOD10    0    0    0    0    0    1    7    1    3    7    1    3    7    1\r\n091601 091601 MOD10    0    0    3    7    1    3    7    1    3    7    1    3    7    1\r\n091740 091743 MOD10    0    0    0    0    0    1    7    1    3    7    1    3    7    1\r\n091800 091809 MOD10    0    0    0    0    0    1    7    1    3    7    1    3    7    1\r\n091811 091865 MOD10    0    0    0    0    0    1    7    1    3    7    1    3    7    1\r\n100000 101099 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n101101 101498 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n101500 101999 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n102400 107999 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n108000 108079 MOD11    0    0    0    0    0    3    2    7    6    5    4    3    2    1\r\n108080 108099 MOD11    0    0    0    0    4    3    2    7    6    5    4    3    2    1\r\n108100 109999 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n110000 119280 DBLAL    0    0    2    1    2    1    2    1    2    1    2    1    2    1   1\r\n119282 119283 DBLAL    0    0    2    1    2    1    2    1    2    1    2    1    2    1   1\r\n119285 119999 DBLAL    0    0    2    1    2    1    2    1    2    1    2    1    2    1   1\r\n120000 120961 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n120963 122009 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n122011 122101 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n122103 122129 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n122131 122135 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n122213 122299 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n122400 122999 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n124000 124999 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n133000 133999 MOD11    0    0    0    0    0   10    7    8    4    6    3    5    2    1\r\n134012 134020 MOD11    0    0    0    7    5    9    8    4    6    3    5    2    0    0   4\r\n134121 134121 MOD11    0    0    0    1    0    0    8    4    6    3    5    2    0    0   4\r\n150000 158000 MOD11    4    3    0    0    0    0    2    7    6    5    4    3    2    1\r\n159800 159800 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n159900 159900 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n159910 159910 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n160000 161027 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161029 161029 MOD11    0    0    0    0    0    0    2    7    6    5    4    3    2    1\r\n161030 161041 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161050 161050 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161055 161055 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161060 161060 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161065 161065 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161070 161070 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161075 161075 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161080 161080 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161085 161085 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161090 161090 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n161100 162028 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n162030 164300 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n165901 166001 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n166050 167600 MOD11    0    0    6    5    4    3    2    7    6    5    4    3    2    1\r\n168600 168600 MOD11    0    0    0    0    0    0    2    7    6    5    4    3    2    1\r\n180002 180002 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180005 180005 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180009 180009 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180036 180036 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180038 180038 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180091 180092 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180104 180104 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180109 180110 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n180156 180156 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n185001 185001 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1  14\r\n185003 185009 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n185011 185025 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n185027 185099 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n200000 200002 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200000 200002 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200004 200004 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200004 200004 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200026 200026 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200026 200026 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200051 200077 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200051 200077 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200079 200097 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200079 200097 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200099 200156 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200099 200156 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200158 200387 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200158 200387 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200403 200405 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200403 200405 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200407 200407 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200407 200407 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200411 200412 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200411 200412 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200414 200423 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200414 200423 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200425 200899 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200425 200899 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n200901 201159 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n200901 201159 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n201161 201177 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n201161 201177 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n201179 201351 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n201179 201351 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n201353 202698 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n201353 202698 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n202700 203239 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n202700 203239 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n203241 203255 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n203241 203255 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n203259 203519 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n203259 203519 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n203521 204476 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n203521 204476 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n204478 205475 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n204478 205475 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n205477 205954 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n205477 205954 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n205956 206124 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n205956 206124 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n206126 206157 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n206126 206157 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n206159 206390 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n206159 206390 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n206392 206799 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n206392 206799 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n206802 206874 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n206802 206874 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n206876 207170 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n206876 207170 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n207173 208092 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n207173 208092 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n208094 208721 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n208094 208721 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n208723 209034 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n208723 209034 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n209036 209128 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n209036 209128 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n209130 209999 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1   6\r\n209130 209999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   6\r\n230088 230088 MOD10    2    1    2    1    2    1    2    7    4    5    6    3    8    1\r\n230338 230338 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n230338 230338 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n230580 230580 MOD11    0    0    0    0    0    0    2    7    6    5    4    3    2    1  12\r\n230580 230580 MOD11    0    0    0    0    0    0    5    7    6    5    4    3    2    1  13\r\n230614 230614 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n230614 230614 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n230709 230709 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n230709 230709 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n230872 230872 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n230872 230872 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n230933 230933 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n230933 230933 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231018 231018 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231018 231018 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231213 231213 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231213 231213 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231228 231228 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231228 231228 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231354 231354 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231354 231354 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231469 231469 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231469 231469 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231558 231558 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231558 231558 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231618 231618 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231618 231618 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231679 231679 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231679 231679 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231843 231843 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231843 231843 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n231985 231985 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n231985 231985 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232130 232130 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232130 232130 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232279 232279 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232279 232279 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232283 232283 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232283 232283 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232290 232290 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232445 232445 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232445 232445 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232571 232571 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232571 232571 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232636 232636 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232636 232636 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232704 232704 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232704 232704 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232725 232725 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232725 232725 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232813 232813 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232813 232813 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n232939 232939 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n232939 232939 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233080 233080 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233080 233080 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233135 233135 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233135 233135 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233142 233142 MOD10    2    1    2    1    2    1   30   36   24   20   16   12    8    4\r\n233171 233171 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233171 233171 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233188 233188 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233188 233188 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233231 233231 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233231 233231 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233344 233344 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233344 233344 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233438 233438 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233438 233438 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233456 233456 MOD10    2    1    2    1    2    1    0   64   32   16    8    4    2    1\r\n233483 233483 MOD11    0    0    0    0    0    0    2    7    6    5    4    3    2    1\r\n233556 233556 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233556 233556 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233658 233658 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233658 233658 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233693 233693 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233693 233693 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n233752 233752 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n233752 233752 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234081 234081 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234081 234081 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234193 234193 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234193 234193 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234252 234252 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234252 234252 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234321 234321 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234321 234321 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234377 234377 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234377 234377 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234570 234570 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234570 234570 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234666 234666 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234666 234666 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234779 234779 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234779 234779 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234828 234828 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234828 234828 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n234985 234985 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n234985 234985 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235054 235054 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235054 235054 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235164 235164 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235164 235164 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235262 235262 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235262 235262 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235323 235323 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235323 235323 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235451 235451 MOD11    0    0    0    0    0    0    2    7    6    5    4    3    2    1\r\n235459 235459 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235459 235459 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235519 235519 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235519 235519 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235676 235676 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235676 235676 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235711 235711 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235711 235711 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235756 235756 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235756 235756 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n235889 235889 MOD10    2    1    2    1    2    1    0   64   32   16    8    4    2    1\r\n235945 235945 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n235945 235945 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236006 236006 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236006 236006 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236119 236119 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236119 236119 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236233 236233 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236233 236233 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236247 236247 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n236293 236293 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236293 236293 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236422 236422 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236422 236422 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236527 236527 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236527 236527 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236538 236538 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236538 236538 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236643 236643 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236643 236643 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236761 236761 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236761 236761 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236907 236907 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n236907 236907 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n236972 236972 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237130 237130 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237130 237130 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237265 237265 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237265 237265 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237355 237355 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237355 237355 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237423 237423 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237423 237423 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237427 237427 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237427 237427 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237563 237563 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237563 237563 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237622 237622 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237622 237622 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237728 237728 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237728 237728 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n237873 237873 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n237873 237873 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238020 238020 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238020 238020 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238043 238043 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238043 238043 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238051 238051 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238051 238051 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238175 238175 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238175 238175 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238257 238257 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238257 238257 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238392 238431 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n238392 238431 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238432 238432 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238432 238432 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238433 238583 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n238433 238583 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238585 238590 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n238585 238590 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238599 238599 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238599 238599 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238613 238613 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238613 238613 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238672 238672 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238672 238672 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238717 238717 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238717 238717 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n238890 238899 MOD11    0    0    0    0    4    3    2    7    6    5    4    3    2    1\r\n238908 238908 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n238908 238908 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239071 239071 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239071 239071 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239126 239126 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239126 239126 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239136 239140 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n239136 239140 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239143 239144 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n239143 239144 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239282 239283 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n239282 239283 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239285 239294 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n239285 239294 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239295 239295 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239295 239295 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239296 239318 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n239296 239318 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239360 239360 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239360 239360 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239380 239380 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239380 239380 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239435 239435 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239435 239435 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239525 239525 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239525 239525 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239642 239642 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239642 239642 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n239751 239751 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n239751 239751 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n300000 300006 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n300000 300006 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n300008 300009 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n300008 300009 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n300050 300051 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n300134 300138 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n300134 300138 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n300161 300161 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1\r\n300176 300176 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1\r\n301001 301001 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301001 301001 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301004 301004 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301004 301004 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301007 301007 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301007 301007 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301012 301012 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301012 301012 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301022 301022 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301027 301027 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301047 301047 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301047 301047 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301049 301049 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301049 301049 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301052 301052 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301052 301052 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301075 301076 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301075 301076 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301108 301108 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301108 301108 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301112 301112 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301112 301112 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301127 301127 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301127 301127 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301137 301137 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301142 301142 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301148 301148 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301148 301148 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301154 301155 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301161 301161 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301161 301161 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301166 301166 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301170 301170 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301174 301175 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301174 301175 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301191 301191 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301191 301191 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301194 301195 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301194 301195 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301204 301205 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301204 301205 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301209 301210 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301209 301210 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301215 301215 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301215 301215 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301218 301218 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301218 301218 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301220 301221 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301220 301221 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301234 301234 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301234 301234 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301251 301251 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301251 301251 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301259 301259 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301259 301259 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301274 301274 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301274 301274 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301280 301280 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301280 301280 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301286 301286 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301286 301286 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301295 301296 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301295 301296 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301299 301299 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301299 301299 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301301 301301 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301301 301301 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301305 301305 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301305 301305 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301318 301318 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301318 301318 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301330 301330 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301330 301330 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301332 301332 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301332 301332 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301335 301335 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301335 301335 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301342 301342 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301342 301342 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301350 301355 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301350 301355 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301364 301364 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301364 301364 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301368 301368 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301368 301368 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301376 301376 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301376 301376 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301380 301380 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301380 301380 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301388 301388 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301388 301388 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301390 301390 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301390 301390 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301395 301395 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301395 301395 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301400 301400 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301400 301400 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301424 301424 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301424 301424 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301432 301432 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301432 301432 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301433 301433 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301435 301435 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301437 301437 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301437 301437 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301439 301439 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301440 301440 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301440 301440 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301443 301443 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301444 301444 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301444 301444 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301447 301447 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301447 301447 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301451 301451 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301451 301451 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301456 301456 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301456 301456 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301458 301458 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301460 301460 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301460 301460 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301463 301463 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301464 301464 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301464 301464 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301466 301466 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301469 301469 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301469 301469 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301471 301471 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301471 301471 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301474 301474 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301477 301477 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301477 301477 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301482 301482 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301483 301483 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301483 301483 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301485 301485 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301487 301487 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301504 301504 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301504 301504 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301510 301510 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301514 301514 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301517 301517 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301525 301525 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301539 301539 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301539 301539 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301542 301542 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301542 301542 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301552 301553 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301552 301553 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301557 301557 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301557 301557 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301573 301573 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301593 301593 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301593 301593 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301595 301595 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301595 301595 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301597 301597 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301597 301597 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301599 301599 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301599 301599 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301607 301607 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301609 301609 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301609 301609 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301611 301611 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301611 301611 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301620 301620 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301620 301620 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301628 301628 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301628 301628 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301634 301634 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301634 301634 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301641 301642 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301641 301642 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301653 301653 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301653 301653 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301657 301657 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301662 301662 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301662 301662 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301664 301664 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301664 301664 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301670 301670 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301670 301670 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301674 301674 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301674 301674 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301684 301684 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301684 301684 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301695 301696 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301695 301696 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301700 301702 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301700 301702 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301705 301705 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n301712 301712 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301712 301712 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301716 301716 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301716 301716 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301748 301748 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301748 301748 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301773 301773 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301773 301773 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301777 301777 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301777 301777 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301780 301780 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301780 301780 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301785 301785 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301785 301785 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301803 301803 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301803 301803 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301805 301805 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301805 301805 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301806 301806 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301806 301806 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301816 301816 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301816 301816 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301825 301825 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301825 301825 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301830 301830 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301830 301830 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301834 301834 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301834 301834 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301843 301843 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301843 301843 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301845 301845 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301845 301845 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301855 301856 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301855 301856 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301864 301864 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301864 301864 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301868 301869 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301868 301869 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301883 301883 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301883 301883 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301886 301888 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301886 301888 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301898 301898 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301898 301898 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n301914 301996 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n301914 301996 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n302500 302500 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n302500 302500 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n302556 302556 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n302556 302556 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n302579 302580 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n302579 302580 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n302880 302880 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n303460 303461 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n303460 303461 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n304065 304067 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1\r\n305907 305939 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305907 305939 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305941 305960 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305941 305960 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305971 305971 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305971 305971 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305974 305974 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305974 305974 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305978 305978 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305978 305978 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305982 305982 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305982 305982 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305984 305988 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305984 305988 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n305990 305993 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n305990 305993 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306017 306018 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306017 306018 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306020 306020 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306020 306020 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306028 306028 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306028 306028 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306038 306038 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306038 306038 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306150 306151 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306150 306151 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306154 306155 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306154 306155 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306228 306228 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306228 306228 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306229 306229 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306229 306229 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306232 306232 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306232 306232 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306242 306242 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306242 306242 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306245 306245 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306245 306245 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306249 306249 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306249 306249 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306255 306255 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306255 306255 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306259 306263 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306259 306263 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306272 306279 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306272 306279 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306281 306281 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306281 306281 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306289 306289 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306289 306289 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306296 306296 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306296 306296 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306299 306299 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306299 306299 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306300 306300 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306300 306300 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306347 306347 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306347 306347 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306354 306355 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306354 306355 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306357 306357 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306357 306357 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306359 306359 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306359 306359 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306364 306364 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306364 306364 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306394 306394 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306394 306394 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306397 306397 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306397 306397 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306410 306410 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306410 306410 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306412 306412 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306412 306412 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306414 306415 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306414 306415 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306418 306419 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306418 306419 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306422 306422 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306422 306422 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306434 306434 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306434 306434 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306437 306438 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306437 306438 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306442 306444 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306442 306444 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306457 306457 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306457 306457 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306472 306472 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306472 306472 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306479 306479 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306479 306479 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306497 306497 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306497 306497 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306521 306522 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306521 306522 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306537 306539 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306537 306539 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306541 306541 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306541 306541 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306549 306549 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306549 306549 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306562 306565 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306562 306565 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306572 306572 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306572 306572 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306585 306586 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306585 306586 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306592 306593 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306592 306593 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306675 306677 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306675 306677 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306689 306689 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306689 306689 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306695 306696 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306695 306696 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306733 306735 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306733 306735 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306747 306749 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306747 306749 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306753 306753 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306753 306753 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306756 306756 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306756 306756 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306759 306759 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306759 306759 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306762 306762 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306762 306762 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306764 306764 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306764 306764 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306766 306767 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306766 306767 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306769 306769 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306769 306769 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306772 306772 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306772 306772 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306775 306776 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306775 306776 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306779 306779 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306779 306779 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306782 306782 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306782 306782 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306788 306789 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306788 306789 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n306799 306799 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n306799 306799 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307184 307184 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307184 307184 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307188 307190 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307188 307190 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307198 307198 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307198 307198 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307271 307271 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307271 307271 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307274 307274 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307274 307274 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307654 307654 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307654 307654 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307779 307779 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307779 307779 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307788 307789 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307788 307789 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n307809 307809 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n307809 307809 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308012 308012 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308012 308012 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308016 308016 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308016 308016 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308026 308027 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308026 308027 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308033 308034 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308033 308034 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308037 308037 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308037 308037 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308042 308042 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308042 308042 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308045 308045 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308045 308045 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308048 308049 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308048 308049 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308054 308055 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308054 308055 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308063 308063 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308063 308063 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308076 308077 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308076 308077 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308082 308083 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308082 308083 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308085 308085 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308085 308085 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308087 308089 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308087 308089 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308095 308097 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308095 308097 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308404 308404 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308404 308404 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308412 308412 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308412 308412 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308420 308427 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308420 308427 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308433 308434 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308433 308434 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308441 308446 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308441 308446 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308448 308448 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308448 308448 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308451 308454 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308451 308454 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308457 308459 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308457 308459 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308462 308463 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308462 308463 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308467 308469 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308467 308469 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308472 308473 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308472 308473 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308475 308477 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308475 308477 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308479 308479 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308479 308479 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308482 308482 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308482 308482 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308484 308487 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308484 308487 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308784 308784 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308784 308784 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308804 308804 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308804 308804 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308822 308822 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308822 308822 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n308952 308952 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n308952 308952 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n309001 309633 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n309001 309633 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n309634 309634 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1\r\n309635 309746 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n309635 309746 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n309748 309871 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n309748 309871 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n309873 309915 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n309873 309915 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n309917 309999 MOD11    0    0    3    2    9    8    5    7    6    5    4    3    2    1   2\r\n309917 309999 MOD11    0    0    3    2    9    8    1    7    6    5    4    3    2    1   9\r\n400000 400193 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n400000 400193 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n400196 400514 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n400196 400514 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n400515 400515 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n400516 401054 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n400516 401054 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401055 401055 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401056 401198 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401056 401198 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401199 401199 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401200 401265 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401200 401265 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401266 401266 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401267 401275 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401267 401275 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401276 401279 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401280 401899 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401280 401899 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401900 401900 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401901 401949 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401901 401949 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n401950 401950 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n401951 404374 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n401951 404374 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n404375 404384 MOD11    0    0    0    0    0    0    8    5    7    3    4    9    2    1\r\n404385 404799 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n404385 404799 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n406420 406420 MOD10    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n500000 501029 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n502101 560070 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600000 600108 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600110 600124 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600127 600142 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600144 600149 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600180 600304 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600307 600312 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600314 600355 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600357 600851 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n600901 601360 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n601403 608028 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n608301 608301 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n608316 608316 MOD10    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n608370 608370 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n608371 608371 MOD11    0    0    0    0    0    0    2    8    4    3    7    5    6    1\r\n609593 609593 MOD10    0    0    0    0    0    0    7    1    3    7    1    3    7    1\r\n609599 609599 MOD10    0    0    0    0    0    0    0    5    7    5    2    1    2    1\r\n640001 640001 MOD11    0    0    0    0    0    0    8    7    6    5    4    3    2    1\r\n720000 720249 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n720251 724443 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n725000 725251 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n725253 725616 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n726000 726616 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n770100 771799 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n771877 771877 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n771900 772799 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n772813 772817 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n772901 773999 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n774100 774599 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n774700 774830 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n774832 777789 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n777791 777999 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n778001 778001 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n778300 778799 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n778855 778855 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n778900 779174 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n779414 779999 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1   7\r\n800000 802005 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802007 802042 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802044 802065 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802067 802109 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802111 802114 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802116 802123 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802151 802154 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802156 802179 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n802181 803599 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n803609 819999 MOD11    0    0    1    8    2    6    3    7    9    5    8    4    2    1\r\n820000 826917 MOD11    0    0    0    0    0    0    0    0    7    3    4    9    2    1\r\n820000 826917 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   3\r\n826919 827999 MOD11    0    0    0    0    0    0    0    0    7    3    4    9    2    1\r\n826919 827999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   3\r\n829000 829999 MOD11    0    0    0    0    0    0    0    0    7    3    4    9    2    1\r\n829000 829999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1   3\r\n830000 835700 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836500 836501 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836505 836506 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836510 836510 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836515 836515 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836530 836530 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836535 836535 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836540 836540 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836560 836560 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836565 836565 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836570 836570 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836585 836585 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836590 836590 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836595 836595 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836620 836620 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836625 836625 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n836630 836630 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n837550 837550 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n837560 837560 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n837570 837570 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n837580 837580 MOD11    0    0    4    3    2    7    2    7    6    5    4    3    2    1\r\n839105 839106 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n839105 839106 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n839130 839131 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    1    0\r\n839130 839131 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n839147 839147 MOD10    0    0    0    0    0    0    0    5    7    5    2    1    2    1\r\n870000 872791 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n870000 872791 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n872793 876899 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n872793 876899 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876919 876919 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876919 876919 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876921 876923 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876921 876923 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876925 876932 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876925 876932 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876935 876935 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876935 876935 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876951 876951 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876951 876951 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876953 876955 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876953 876955 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876957 876957 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876957 876957 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n876961 876965 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n876961 876965 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877000 877070 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877000 877070 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877071 877071 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877071 877071 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877078 877078 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877078 877078 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877088 877088 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877088 877088 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877090 877090 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877090 877090 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877098 877098 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877098 877098 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n877099 879999 MOD11    0    0    1    2    5    3    6    4    8    7   10    9    3    1  10\r\n877099 879999 MOD11    0    0    5   10    9    8    0    7    6    5    4    3    2    1  11\r\n890000 890699 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n891000 891616 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n892000 892616 MOD11    0    0    0    0    0    9    8    7    6    5    4    3    2    1\r\n900000 902396 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n900000 902396 MOD11   32   16    8    4    2    1    0    0    0    0    0    0    0    0\r\n902398 909999 MOD11    0    0    0    0    0    0  128   64   32   16    8    4    2    1\r\n902398 909999 MOD11   32   16    8    4    2    1    0    0    0    0    0    0    0    0\r\n938000 938696 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    0    0   5\r\n938000 938696 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    0   5\r\n938698 938999 MOD11    7    6    5    4    3    2    7    6    5    4    3    2    0    0   5\r\n938698 938999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    0   5\r\n950000 950002 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n950000 950002 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n950004 950479 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n950004 950479 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n950500 959999 MOD11    0    0    0    0    0    0    0    7    6    5    4    3    2    1\r\n950500 959999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n980000 980004 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n980000 980004 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n980006 983000 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n980006 983000 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n983003 987000 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n983003 987000 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n987004 989999 MOD11    0    0    0    0    0    0    7    6    5    4    3    2    1    0\r\n987004 989999 DBLAL    2    1    2    1    2    1    2    1    2    1    2    1    2    1\r\n';
      var valacdos = [];

      content.split('\r\n').forEach(function (line) {
        var data = line.split(/\s+/);

        /* jscs:disable validateOrderInObjectKeys */
        valacdos.push({
          start: parseInt(data[0], 10),
          end: parseInt(data[1], 10),
          mod: data[2],
          u: parseInt(data[3], 10),
          v: parseInt(data[4], 10),
          w: parseInt(data[5], 10),
          x: parseInt(data[6], 10),
          y: parseInt(data[7], 10),
          z: parseInt(data[8], 10),
          a: parseInt(data[9], 10),
          b: parseInt(data[10], 10),
          c: parseInt(data[11], 10),
          d: parseInt(data[12], 10),
          e: parseInt(data[13], 10),
          f: parseInt(data[14], 10),
          g: parseInt(data[15], 10),
          h: parseInt(data[16], 10),
          exception: parseInt(data[17], 10) || null
        });
        /* jscs:enable validateOrderInObjectKeys */
      });

      return valacdos;
    }

    /**
     * Pick position in number.
     */

  }, {
    key: 'pickPosition',
    value: function pickPosition(number, position) {
      return parseInt(number.charAt(_constants.positions[position]), 10);
    }

    /**
     * Sanitize.
     */

  }, {
    key: 'sanitize',
    value: function sanitize(value) {
      if (typeof value === 'string' || value instanceof String) {
        return value.replace(/-/g, '');
      }

      throw new Error('Invalid value');
    }
  }]);

  return UkModulusChecking;
}();

exports.default = UkModulusChecking;
module.exports = exports['default'];